@@ -17,6 +17,11 @@ from init_helpers.dict_to_dataclass import dict_to_dataclass
 logger = logging.getLogger(__name__)
 
 
+def construct_origin_from_referer(referer: str) -> str:
+    prefix, path = referer.split("://", 1)
+    return f"{prefix}://{path.split('/')[0]}"
+
+
 class TokenId(str):
     pass
 
